@@ -27,5 +27,7 @@ export const SUGGESTER_ENDPOINTS = [
   'survey',
   'sensitiveLabTestCategory',
   'nonSensitiveLabTestCategory',
+  'role',
+  'encounter',
   'reportDefinition',
 ];
